@@ -209,7 +209,7 @@ class Figure:
                 Defaults to ``f'{folder_path}/{filename}'``.
             folder_path (str, optional): Called when :attr:`path` is ``None``.
                 Defaults to :attr:`~self.folder_path`.
-            folder_path (str, optional): Called when :attr:`path` is ``None``.
+            filename (str, optional): Called when :attr:`path` is ``None``.
                 Defaults to ``f'{name}{ext}'``.
             name (str, optional): Called when :attr:`path` is ``None``.
                 Defaults to :attr:`self.name`.
@@ -474,7 +474,8 @@ class Figure:
                  linewidth: int = 2, linestyle: str = '-',
                  label: str = None, markerfacecolor: str = 'white',
                  zorder: float = 1, **kwargs) -> 'Line2D':
-        r"""A similar implementation to :any:`seaborn.lineplot() <seaborn.lineplot>`.
+        r"""A similar implementation to
+        :any:`seaborn.lineplot() <seaborn.lineplot>`.
         same x value with different y values will result in
         the error band/bar at that x.
 
